@@ -9,8 +9,14 @@ from typing import Awaitable, List, Optional, Tuple, Union, cast, overload
 
 from .. import to_thread
 from ..abc import (
-    ConnectedUDPSocket, IPAddressType, IPSockAddrType, SocketListener, SocketStream, UDPSocket,
-    UNIXSocketStream)
+    ConnectedUDPSocket,
+    IPAddressType,
+    IPSockAddrType,
+    SocketListener,
+    SocketStream,
+    UDPSocket,
+    UNIXSocketStream,
+)
 from ..streams.stapled import MultiListener
 from ..streams.tls import TLSStream
 from ._eventloop import get_asynclib
@@ -23,20 +29,28 @@ if sys.version_info >= (3, 8):
 else:
     from typing_extensions import Literal
 
-IPPROTO_IPV6 = getattr(socket, 'IPPROTO_IPV6', 41)  # https://bugs.python.org/issue29515
+IPPROTO_IPV6 = getattr(socket, "IPPROTO_IPV6", 41)  # https://bugs.python.org/issue29515
 
-GetAddrInfoReturnType = List[Tuple[AddressFamily, SocketKind, int, str, Tuple[str, int]]]
-AnyIPAddressFamily = Literal[AddressFamily.AF_UNSPEC, AddressFamily.AF_INET,
-                             AddressFamily.AF_INET6]
+GetAddrInfoReturnType = List[
+    Tuple[AddressFamily, SocketKind, int, str, Tuple[str, int]]
+]
+AnyIPAddressFamily = Literal[
+    AddressFamily.AF_UNSPEC, AddressFamily.AF_INET, AddressFamily.AF_INET6
+]
 IPAddressFamily = Literal[AddressFamily.AF_INET, AddressFamily.AF_INET6]
 
 
 # tls_hostname given
 @overload
 async def connect_tcp(
-    remote_host: IPAddressType, remote_port: int, *, local_host: Optional[IPAddressType] = ...,
-    ssl_context: Optional[ssl.SSLContext] = ..., tls_standard_compatible: bool = ...,
-    tls_hostname: str, happy_eyeballs_delay: float = ...
+    remote_host: IPAddressType,
+    remote_port: int,
+    *,
+    local_host: Optional[IPAddressType] = ...,
+    ssl_context: Optional[ssl.SSLContext] = ...,
+    tls_standard_compatible: bool = ...,
+    tls_hostname: str,
+    happy_eyeballs_delay: float = ...,
 ) -> TLSStream:
     ...
 
@@ -44,9 +58,14 @@ async def connect_tcp(
 # ssl_context given
 @overload
 async def connect_tcp(
-    remote_host: IPAddressType, remote_port: int, *, local_host: Optional[IPAddressType] = ...,
-    ssl_context: ssl.SSLContext, tls_standard_compatible: bool = ...,
-    tls_hostname: Optional[str] = ..., happy_eyeballs_delay: float = ...
+    remote_host: IPAddressType,
+    remote_port: int,
+    *,
+    local_host: Optional[IPAddressType] = ...,
+    ssl_context: ssl.SSLContext,
+    tls_standard_compatible: bool = ...,
+    tls_hostname: Optional[str] = ...,
+    happy_eyeballs_delay: float = ...,
 ) -> TLSStream:
     ...
 
@@ -54,10 +73,15 @@ async def connect_tcp(
 # tls=True
 @overload
 async def connect_tcp(
-    remote_host: IPAddressType, remote_port: int, *, local_host: Optional[IPAddressType] = ...,
-    tls: Literal[True], ssl_context: Optional[ssl.SSLContext] = ...,
-    tls_standard_compatible: bool = ..., tls_hostname: Optional[str] = ...,
-    happy_eyeballs_delay: float = ...
+    remote_host: IPAddressType,
+    remote_port: int,
+    *,
+    local_host: Optional[IPAddressType] = ...,
+    tls: Literal[True],
+    ssl_context: Optional[ssl.SSLContext] = ...,
+    tls_standard_compatible: bool = ...,
+    tls_hostname: Optional[str] = ...,
+    happy_eyeballs_delay: float = ...,
 ) -> TLSStream:
     ...
 
@@ -65,10 +89,15 @@ async def connect_tcp(
 # tls=False
 @overload
 async def connect_tcp(
-    remote_host: IPAddressType, remote_port: int, *, local_host: Optional[IPAddressType] = ...,
-    tls: Literal[False], ssl_context: Optional[ssl.SSLContext] = ...,
-    tls_standard_compatible: bool = ..., tls_hostname: Optional[str] = ...,
-    happy_eyeballs_delay: float = ...
+    remote_host: IPAddressType,
+    remote_port: int,
+    *,
+    local_host: Optional[IPAddressType] = ...,
+    tls: Literal[False],
+    ssl_context: Optional[ssl.SSLContext] = ...,
+    tls_standard_compatible: bool = ...,
+    tls_hostname: Optional[str] = ...,
+    happy_eyeballs_delay: float = ...,
 ) -> SocketStream:
     ...
 
@@ -76,17 +105,25 @@ async def connect_tcp(
 # No TLS arguments
 @overload
 async def connect_tcp(
-    remote_host: IPAddressType, remote_port: int, *, local_host: Optional[IPAddressType] = ...,
-    happy_eyeballs_delay: float = ...
+    remote_host: IPAddressType,
+    remote_port: int,
+    *,
+    local_host: Optional[IPAddressType] = ...,
+    happy_eyeballs_delay: float = ...,
 ) -> SocketStream:
     ...
 
 
 async def connect_tcp(
-    remote_host: IPAddressType, remote_port: int, *, local_host: Optional[IPAddressType] = None,
-    tls: bool = False, ssl_context: Optional[ssl.SSLContext] = None,
-    tls_standard_compatible: bool = True, tls_hostname: Optional[str] = None,
-    happy_eyeballs_delay: float = 0.25
+    remote_host: IPAddressType,
+    remote_port: int,
+    *,
+    local_host: Optional[IPAddressType] = None,
+    tls: bool = False,
+    ssl_context: Optional[ssl.SSLContext] = None,
+    tls_standard_compatible: bool = True,
+    tls_hostname: Optional[str] = None,
+    happy_eyeballs_delay: float = 0.25,
 ) -> Union[SocketStream, TLSStream]:
     """
     Connect to a host using the TCP protocol.
@@ -149,8 +186,9 @@ async def connect_tcp(
         addr_obj = ip_address(remote_host)
     except ValueError:
         # getaddrinfo() will raise an exception if name resolution fails
-        gai_res = await getaddrinfo(target_host, remote_port, family=family,
-                                    type=socket.SOCK_STREAM)
+        gai_res = await getaddrinfo(
+            target_host, remote_port, family=family, type=socket.SOCK_STREAM
+        )
 
         # Organize the list so that the first address is an IPv6 address (if available) and the
         # second one is an IPv4 addresses. The rest can be in whatever order.
@@ -181,14 +219,17 @@ async def connect_tcp(
 
     if connected_stream is None:
         cause = oserrors[0] if len(oserrors) == 1 else asynclib.ExceptionGroup(oserrors)
-        raise OSError('All connection attempts failed') from cause
+        raise OSError("All connection attempts failed") from cause
 
     if tls or tls_hostname or ssl_context:
         try:
-            return await TLSStream.wrap(connected_stream, server_side=False,
-                                        hostname=tls_hostname or str(remote_host),
-                                        ssl_context=ssl_context,
-                                        standard_compatible=tls_standard_compatible)
+            return await TLSStream.wrap(
+                connected_stream,
+                server_side=False,
+                hostname=tls_hostname or str(remote_host),
+                ssl_context=ssl_context,
+                standard_compatible=tls_standard_compatible,
+            )
         except BaseException:
             await aclose_forcefully(connected_stream)
             raise
@@ -196,7 +237,7 @@ async def connect_tcp(
     return connected_stream
 
 
-async def connect_unix(path: Union[str, 'PathLike[str]']) -> UNIXSocketStream:
+async def connect_unix(path: Union[str, "PathLike[str]"]) -> UNIXSocketStream:
     """
     Connect to the given UNIX socket.
 
@@ -211,9 +252,12 @@ async def connect_unix(path: Union[str, 'PathLike[str]']) -> UNIXSocketStream:
 
 
 async def create_tcp_listener(
-    *, local_host: Optional[IPAddressType] = None, local_port: int = 0,
-    family: AnyIPAddressFamily = socket.AddressFamily.AF_UNSPEC, backlog: int = 65536,
-    reuse_port: bool = False
+    *,
+    local_host: Optional[IPAddressType] = None,
+    local_port: int = 0,
+    family: AnyIPAddressFamily = socket.AddressFamily.AF_UNSPEC,
+    backlog: int = 65536,
+    reuse_port: bool = False,
 ) -> MultiListener[SocketStream]:
     """
     Create a TCP socket listener.
@@ -233,9 +277,13 @@ async def create_tcp_listener(
     asynclib = get_asynclib()
     backlog = min(backlog, 65536)
     local_host = str(local_host) if local_host is not None else None
-    gai_res = await getaddrinfo(local_host, local_port, family=family,  # type: ignore[arg-type]
-                                type=socket.SOCK_STREAM,
-                                flags=socket.AI_PASSIVE | socket.AI_ADDRCONFIG)
+    gai_res = await getaddrinfo(
+        local_host,  # type: ignore[arg-type]
+        local_port,
+        family=family,
+        type=socket.SOCK_STREAM,
+        flags=socket.AI_PASSIVE | socket.AI_ADDRCONFIG,
+    )
     listeners: List[SocketListener] = []
     try:
         # The set() is here to work around a glibc bug:
@@ -245,7 +293,7 @@ async def create_tcp_listener(
             raw_socket.setblocking(False)
 
             # For Windows, enable exclusive address use. For others, enable address reuse.
-            if sys.platform == 'win32':
+            if sys.platform == "win32":
                 raw_socket.setsockopt(socket.SOL_SOCKET, socket.SO_EXCLUSIVEADDRUSE, 1)
             else:
                 raw_socket.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
@@ -271,8 +319,11 @@ async def create_tcp_listener(
 
 
 async def create_unix_listener(
-        path: Union[str, 'PathLike[str]'], *, mode: Optional[int] = None,
-        backlog: int = 65536) -> SocketListener:
+    path: Union[str, "PathLike[str]"],
+    *,
+    mode: Optional[int] = None,
+    backlog: int = 65536,
+) -> SocketListener:
     """
     Create a UNIX socket listener.
 
@@ -309,8 +360,11 @@ async def create_unix_listener(
 
 
 async def create_udp_socket(
-    family: AnyIPAddressFamily = AddressFamily.AF_UNSPEC, *,
-    local_host: Optional[IPAddressType] = None, local_port: int = 0, reuse_port: bool = False
+    family: AnyIPAddressFamily = AddressFamily.AF_UNSPEC,
+    *,
+    local_host: Optional[IPAddressType] = None,
+    local_port: int = 0,
+    reuse_port: bool = False,
 ) -> UDPSocket:
     """
     Create a UDP socket.
@@ -331,23 +385,33 @@ async def create_udp_socket(
         raise ValueError('Either "family" or "local_host" must be given')
 
     if local_host:
-        gai_res = await getaddrinfo(str(local_host), local_port, family=family,
-                                    type=socket.SOCK_DGRAM,
-                                    flags=socket.AI_PASSIVE | socket.AI_ADDRCONFIG)
+        gai_res = await getaddrinfo(
+            str(local_host),
+            local_port,
+            family=family,
+            type=socket.SOCK_DGRAM,
+            flags=socket.AI_PASSIVE | socket.AI_ADDRCONFIG,
+        )
         family = cast(AnyIPAddressFamily, gai_res[0][0])
         local_address = gai_res[0][-1]
     elif family is AddressFamily.AF_INET6:
-        local_address = ('::', 0)
+        local_address = ("::", 0)
     else:
-        local_address = ('0.0.0.0', 0)
+        local_address = ("0.0.0.0", 0)
 
-    return await get_asynclib().create_udp_socket(family, local_address, None, reuse_port)
+    return await get_asynclib().create_udp_socket(
+        family, local_address, None, reuse_port
+    )
 
 
 async def create_connected_udp_socket(
-    remote_host: IPAddressType, remote_port: int, *,
+    remote_host: IPAddressType,
+    remote_port: int,
+    *,
     family: AnyIPAddressFamily = AddressFamily.AF_UNSPEC,
-    local_host: Optional[IPAddressType] = None, local_port: int = 0, reuse_port: bool = False
+    local_host: Optional[IPAddressType] = None,
+    local_port: int = 0,
+    reuse_port: bool = False,
 ) -> ConnectedUDPSocket:
     """
     Create a connected UDP socket.
@@ -368,24 +432,36 @@ async def create_connected_udp_socket(
     """
     local_address = None
     if local_host:
-        gai_res = await getaddrinfo(str(local_host), local_port, family=family,
-                                    type=socket.SOCK_DGRAM,
-                                    flags=socket.AI_PASSIVE | socket.AI_ADDRCONFIG)
+        gai_res = await getaddrinfo(
+            str(local_host),
+            local_port,
+            family=family,
+            type=socket.SOCK_DGRAM,
+            flags=socket.AI_PASSIVE | socket.AI_ADDRCONFIG,
+        )
         family = cast(AnyIPAddressFamily, gai_res[0][0])
         local_address = gai_res[0][-1]
 
-    gai_res = await getaddrinfo(str(remote_host), remote_port, family=family,
-                                type=socket.SOCK_DGRAM)
+    gai_res = await getaddrinfo(
+        str(remote_host), remote_port, family=family, type=socket.SOCK_DGRAM
+    )
     family = cast(AnyIPAddressFamily, gai_res[0][0])
     remote_address = gai_res[0][-1]
 
-    return await get_asynclib().create_udp_socket(family, local_address, remote_address,
-                                                  reuse_port)
+    return await get_asynclib().create_udp_socket(
+        family, local_address, remote_address, reuse_port
+    )
 
 
-async def getaddrinfo(host: Union[bytearray, bytes, str], port: Union[str, int, None], *,
-                      family: Union[int, AddressFamily] = 0, type: Union[int, SocketKind] = 0,
-                      proto: int = 0, flags: int = 0) -> GetAddrInfoReturnType:
+async def getaddrinfo(
+    host: Union[bytearray, bytes, str],
+    port: Union[str, int, None],
+    *,
+    family: Union[int, AddressFamily] = 0,
+    type: Union[int, SocketKind] = 0,
+    proto: int = 0,
+    flags: int = 0,
+) -> GetAddrInfoReturnType:
     """
     Look up a numeric IP address given a host name.
 
@@ -409,17 +485,21 @@ async def getaddrinfo(host: Union[bytearray, bytes, str], port: Union[str, int,
     # Handle unicode hostnames
     if isinstance(host, str):
         try:
-            encoded_host = host.encode('ascii')
+            encoded_host = host.encode("ascii")
         except UnicodeEncodeError:
             import idna
+
             encoded_host = idna.encode(host, uts46=True)
     else:
         encoded_host = host
 
-    gai_res = await get_asynclib().getaddrinfo(encoded_host, port, family=family, type=type,
-                                               proto=proto, flags=flags)
-    return [(family, type, proto, canonname, convert_ipv6_sockaddr(sockaddr))
-            for family, type, proto, canonname, sockaddr in gai_res]
+    gai_res = await get_asynclib().getaddrinfo(
+        encoded_host, port, family=family, type=type, proto=proto, flags=flags
+    )
+    return [
+        (family, type, proto, canonname, convert_ipv6_sockaddr(sockaddr))
+        for family, type, proto, canonname, sockaddr in gai_res
+    ]
 
 
 def getnameinfo(sockaddr: IPSockAddrType, flags: int = 0) -> Awaitable[Tuple[str, str]]:
@@ -480,6 +560,7 @@ def wait_socket_writable(sock: socket.socket) -> Awaitable[None]:
 # Private API
 #
 
+
 def convert_ipv6_sockaddr(
     sockaddr: Union[Tuple[str, int, int, int], Tuple[str, int]]
 ) -> Tuple[str, int]:
