@@ -15,12 +15,17 @@ class TaskInfo:
     :ivar ~collections.abc.Coroutine coro: the coroutine object of the task
     """
 
-    __slots__ = '_name', 'id', 'parent_id', 'name', 'coro'
+    __slots__ = "_name", "id", "parent_id", "name", "coro"
 
-    def __init__(self, id: int, parent_id: Optional[int], name: Optional[str],
-                 coro: Union[Generator, Awaitable[Any]]):
+    def __init__(
+        self,
+        id: int,
+        parent_id: Optional[int],
+        name: Optional[str],
+        coro: Union[Generator, Awaitable[Any]],
+    ):
         func = get_current_task
-        self._name = f'{func.__module__}.{func.__qualname__}'
+        self._name = f"{func.__module__}.{func.__qualname__}"
         self.id: int = id
         self.parent_id: Optional[int] = parent_id
         self.name: Optional[str] = name
@@ -36,7 +41,7 @@ class TaskInfo:
         return hash(self.id)
 
     def __repr__(self) -> str:
-        return f'{self.__class__.__name__}(id={self.id!r}, name={self.name!r})'
+        return f"{self.__class__.__name__}(id={self.id!r}, name={self.name!r})"
 
     def __await__(self) -> Generator[None, None, "TaskInfo"]:
         _warn_deprecation(self)
@@ -45,7 +50,7 @@ class TaskInfo:
 
         return self
 
-    def _unwrap(self) -> 'TaskInfo':
+    def _unwrap(self) -> "TaskInfo":
         return self
 
 
